==> org.eclipse.riena.communication.core.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/communication/core/attachment/InputStreamDataSource.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.communication.core.attachment;

import java.io.IOException;
import java.io.InputStream;

import org.eclipse.riena.core.util.Nop;

/**
 *
 */
public class InputStreamDataSource implements IDataSource {

	private InputStream inputStream;

	public InputStreamDataSource(InputStream inputStream) {
		this.inputStream = inputStream;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#getInputStream
	 * ()
	 */
	public InputStream getInputStream() throws IOException {
		try {
			inputStream.reset();
		} catch (IOException e) {
			Nop.reason("catch and ignore"); //$NON-NLS-1$
		}
		return inputStream;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#getName()
	 */
	public String getName() {
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#checkValid()
	 */
	public void checkValid() throws IOException {
		if (inputStream.markSupported()) {
			inputStream.reset();
		}
	}

}

==> org.eclipse.riena.communication.core.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/communication/core/attachment/InputStreamDataSource.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.communication.core.attachment;

import java.io.IOException;
import java.io.InputStream;

import org.eclipse.riena.core.util.Nop;

/**
 *
 */
public class InputStreamDataSource implements IDataSource {

	private final InputStream inputStream;

	public InputStreamDataSource(final InputStream inputStream) {
		this.inputStream = inputStream;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#getInputStream
	 * ()
	 */
	public InputStream getInputStream() throws IOException {
		try {
			inputStream.reset();
		} catch (final IOException e) {
			Nop.reason("catch and ignore"); //$NON-NLS-1$
		}
		return inputStream;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#getName()
	 */
	public String getName() {
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.riena.communication.core.attachment.IDataSource#checkValid()
	 */
	public void checkValid() throws IOException {
		if (inputStream.markSupported()) {
			inputStream.reset();
		}
	}

}
